
/* ========================================================
Beispielcode fr den Versand von SMS ber einen POST-Request
mit der HTTP client API von Java 6 und der
Apache Commons CLI 1.2 API http://commons.apache.org/cli/
Autor: Joachim Nenning info@alphaQuest.de
fr www.sms4.de

Kompilieren mit javac SMS4.java
Ausfhren mit java SMS4 [Parameter]
===========================================================*/

import java.io.*;
import java.net.*;
import org.apache.commons.cli.*;	//Archiv commons-cli-x.y.jar muss dem CLASSPATH hinzugefgt werden


public class SMS4 {

	private static final String KLASSEN_NAME = "SMS4";


	public static void main (String[] args) {

		Console cons = System.console(); //Umlaute ausgeben ermglichen

		//Kommandozeilen-Parser anlegen
		CommandLineParser Parser = new GnuParser();
		HelpFormatter Formatter = new HelpFormatter();

		//Kommandozeilen-Argumente anlegen
		Options Options = new Options();
		
		//boolean Options
 		Option Help = new Option("h", "help", false, "Diese Hilfe anzeigen.");
		Options.addOption(Help);

 		Option Debug = new Option("d", "debug", false, "Debugmodus");
		Options.addOption(Debug);
		
		//argument Options 
    Options.addOption(OptionBuilder
            .withLongOpt("user")
            .withDescription("User (Pflicht)")
            .withValueSeparator('=')
            .hasArg()
            .create("u"));

    Options.addOption(OptionBuilder
            .withLongOpt("passwort")
            .withDescription("Passwort (Pflicht)")
            .withValueSeparator('=')
            .hasArg()
            .create("pw"));

    Options.addOption(OptionBuilder
            .withLongOpt("kundennummer")
            .withDescription("Kundennummer (Pflicht)")
            .withValueSeparator('=')
            .hasArg()
            .create("kdnr"));

    Options.addOption(OptionBuilder
            .withLongOpt("handynummer")
            .withDescription("Handynummer (Pflicht)")
            .withValueSeparator('=')
            .hasArg()
            .create("hnr"));

    Options.addOption(OptionBuilder
            .withLongOpt("text")
            .withDescription("Text der SMS (Pflicht).")
            .withValueSeparator('=')
            .hasArg()
            .create("txt"));

    Options.addOption(OptionBuilder
            .withLongOpt("tarif")
            .withDescription("Tarif 1-5")
            .withValueSeparator('=')
            .hasArg()
            .create("t"));

    Options.addOption(OptionBuilder
            .withLongOpt("a")
            .withDescription("Absenderkennung")
            .withValueSeparator('=')
            .hasArg()
            .create("a"));

		CommandLine Cmd = null;

    try {
        //Kommandozeilen-Argumente parsen
        Cmd = Parser.parse(Options, args);

	        if (Cmd.hasOption("h")) {
						Formatter.printHelp(KLASSEN_NAME, Options);
						System.exit(0);
					}
						
	        if (Cmd.hasOption("d")) {
						System.out.println("User         : " + Cmd.getOptionValue("u"));
						System.out.println("Passwort     : " + Cmd.getOptionValue("pw"));
						System.out.println("Kundennummer : " + Cmd.getOptionValue("kdnr"));
						System.out.println("Handynummer  : " + Cmd.getOptionValue("hnr"));
						System.out.println("Text         : " + Cmd.getOptionValue("txt"));
						System.out.println("Tarif        : " + Cmd.getOptionValue("t"));
						System.out.println("Absender     : " + Cmd.getOptionValue("a"));
						System.out.println("\n");
					}
					
					if ( Cmd.hasOption("u") & Cmd.hasOption("pw") & Cmd.hasOption("kdnr") & Cmd.hasOption("hnr") & Cmd.hasOption("txt") ) {
						String user = Cmd.getOptionValue("u");
						String pw = Cmd.getOptionValue("pw");
						String kdnr = Cmd.getOptionValue("kdnr");
						String handynr = Cmd.getOptionValue("hnr");
						String text = Cmd.getOptionValue("txt");
				    String tarif = "";
				    if (Cmd.hasOption('t')) {
				        tarif = Cmd.getOptionValue("t");
				    }
				    String absender = "";
				    if (Cmd.hasOption('a')) {
				        absender = Cmd.getOptionValue("a");
				    }
				
						// URL zusammenbauen
						String uri ="";
				
						try {
							uri = "handynr=" + URLEncoder.encode(handynr,"ISO-8859-1");
							uri = uri + "&user=" + URLEncoder.encode(user,"ISO-8859-1");
							uri = uri + "&pwd=" + URLEncoder.encode(pw,"ISO-8859-1");
							uri = uri + "&kdnr=" + URLEncoder.encode(kdnr,"ISO-8859-1");
							uri = uri + "&text=" + URLEncoder.encode(text,"ISO-8859-1");
							uri = uri + "&tarif=" + URLEncoder.encode(tarif,"ISO-8859-1");
							uri = uri + "&absender=" + URLEncoder.encode(absender,"ISO-8859-1");
						}
						catch (UnsupportedEncodingException uex) {
							uex.printStackTrace();
						}
				
				    // Zum Schreiben der Daten an das CGI-Skript
				    DataOutputStream output;
				
				    // Stream zum Einlesen der Daten von der URL
				    BufferedReader input;
				
				    // Entsprechende URLConnection zur URL
				    HttpURLConnection connect;
				
						// Aufrufen der URL via POST
						try {
								// Anlegen der URL
								URL url = new URL("http://www.sms4.de/cgi-bin/sms_out.pl");
				      try {
				        /* URLconnection anlegen:
								Da openConnection() ein Exemplar von URLConnection zurckliefert,
								muss ein Cast in HttpURLConnection durchgefhrt werden.
							  */
							  connect = (HttpURLConnection)url.openConnection();
							  connect.setRequestMethod("POST");
							  connect.setUseCaches(false);
				        // Daten an das CGI-Skript schicken
				        connect.setDoOutput(true);
				        output = new DataOutputStream(connect.getOutputStream());
				        output.writeBytes(uri);
				        output.close();
				
							  if (connect.getResponseCode() != HttpURLConnection.HTTP_OK) {
							    System.out.println(connect.getResponseMessage());
							  }
							  else {
							    // Verarbeitung des Ergebnisses
				
									// InputStream erzeugen
									input = new BufferedReader(new InputStreamReader(connect.getInputStream()));
								  String res = "";
				
								  //Meldung ausgeben
								  while ((res = input.readLine()) != null) {
								    cons.printf(res);
								  }
									input.close();
							  }
				      }
				      catch (IOException ex) {
								//HTTP error
								ex.printStackTrace();
				      }
				    }
				    catch(MalformedURLException e) {
				      e.printStackTrace();
				    }	
				    
				  }
				  else {
				  	System.err.println("Missing 1 or more required options\n");
				  	Formatter.printHelp(KLASSEN_NAME, Options);
				  }
    
		    } 
		    catch (ParseException pex) {
		    	System.err.println(pex.getMessage() + "\n");
		    	Formatter.printHelp(KLASSEN_NAME, Options);
		    }

	}

}